cumulusci.core.source package
=============================

Submodules
----------


.. automodule:: cumulusci.core.source.github
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.source.local_folder
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.core.source
   :members:
   :undoc-members:
   :show-inheritance:
